# autogenerated module
from typing import ClassVar

from ..core import resource as res
from ..models import storagemigration_v1alpha1 as m_storagemigration_v1alpha1


class StorageVersionMigrationStatus(res.GlobalSubResource, m_storagemigration_v1alpha1.StorageVersionMigration):
    """* **Extends**: ``models.storagemigration_v1alpha1.StorageVersionMigration``
       * **Type**: Global Resource
       * **Accepted client methods**: `get`, `patch`, `replace`
    """
    _api_info = res.ApiInfo(
        resource=res.ResourceDef('storagemigration.k8s.io', 'v1alpha1', 'StorageVersionMigration'),
        parent=res.ResourceDef('storagemigration.k8s.io', 'v1alpha1', 'StorageVersionMigration'),
        plural='storageversionmigrations',
        verbs=['get', 'patch', 'put'],
        action='status',
    )


class StorageVersionMigration(res.GlobalResource, m_storagemigration_v1alpha1.StorageVersionMigration):
    """* **Extends**: ``models.storagemigration_v1alpha1.StorageVersionMigration``
       * **Type**: Global Resource
       * **Accepted client methods**: `delete`, `deletecollection`, `get`, `list`, `patch`, `create`, `replace`, `watch`

       **Subresources**:

       * **Status**: ``StorageVersionMigrationStatus``
    """
    _api_info = res.ApiInfo(
        resource=res.ResourceDef('storagemigration.k8s.io', 'v1alpha1', 'StorageVersionMigration'),
        plural='storageversionmigrations',
        verbs=['delete', 'deletecollection', 'get', 'list', 'patch', 'post', 'put', 'watch'],
    )

    Status: ClassVar = StorageVersionMigrationStatus

